<?php
if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Minimee: minimize & combine your CSS and JS files. For EE2 only.
 * @version 1.0.2
 * @author John D Wells <http://johndwells.com>
 * @license http://www.opensource.org/licenses/bsd-license.php BSD license
 * @link	http://johndwells.com/software/minimee
 */
class Minimee_ext {

	var $name			= 'Minimee';
	var $version		= '1.0.2';
	var $description	= 'Minimee: minimize & combine your CSS and JS files. For EE2 only.';
	var $settings_exist	= 'y';
	var $docs_url		= 'http://johndwells.com/software/minimee';

	var $settings		= array();
	
	var $EE;

	/**
	 * Constructor
	 *
	 * @param 	mixed	Settings array or empty string if none exist.
	 * @return void
	 */
	function Minimee_ext($settings = array())
	{
		$this->EE =& get_instance();

		// initialise settings array
		$this->settings = array(
			'disable' => FALSE,
			'strict' => FALSE,
			'cache_path' => FALSE,
			'cache_url' => FALSE
		);
	}
	// END


	/**
	 * Activate Extension
	 * @return void
	 */
	function activate_extension()
	{
		$this->settings = array(
			'cache_url'		=> '',
			'cache_path'	=> '',
			'disable'		=> 'false',
			'strict'		=> 'false'
		);
		
		$data = array(
			'class'		=> __CLASS__,
			'settings'	=> serialize($this->settings),
			'priority'	=> 10,
			'version'	=> $this->version,
			'enabled'	=> 'y'
		);
		
		$this->EE->db->insert('extensions', $data);
	}
	// END


	/**
	 * Disable Extension
	 *
	 * @return void
	 */
	function disable_extension()
	{
		$this->EE->db->where('class', __CLASS__);
		$this->EE->db->delete('extensions');
	}
	// END


	/**
	 * Used by plugin, retrieves settings from config, global variables OR database (and in that order)
	 *
	 * @return void
	 */
	function get_settings()
	{
		// if settings are already in session cache, use those
		if (isset($this->EE->session->cache['minimee']['settings']))
		{
			$this->settings = $this->EE->session->cache['minimee']['settings'];
			return;
		}
		
		// see if values exist in global variable or config; if not, look in DB
		if ( ! $this->_get_global_or_config_settings())
		{
			$this->EE->db
						->select('settings')
						->from('extensions')
						->where(array('enabled' => 'y', 'class' => __CLASS__ ))
						->limit(1);
			$query = $this->EE->db->get();
			
			if ($query->num_rows() > 0)
			{
				$this->settings = unserialize($query->row()->settings);
				log_message('debug', 'Minimee has retrieved settings from DB.');
			}
		}

		// normalize settings before adding to session
		$this->_normalize_settings();

		// now set to session for subsequent calls
		if ( ! array_key_exists('minimee', $this->EE->session->cache))
		{
			$this->EE->session->cache['minimee'] = array();
		}
		$this->EE->session->cache['minimee']['settings'] = $this->settings;
		
	}
	// END


	/**
	 * Minimal function required to use DB settings
	 *
	 * @return void
	 */
	function settings()
	{
		$settings = array();

		$settings['cache_path'] = '';
		$settings['cache_url'] = '';
		$settings['disable'] = array('r', array('false' => 'No', 'true' => 'Yes'), 'false');
		$settings['strict'] = array('r', array('false' => 'No', 'true' => 'Yes'), 'false');

		return $settings;
	}
	// END


	/**
	 * Update Extension
	 *
	 * @param 	string	String value of current version
	 * @return 	mixed	void on update / false if none
	 */
	function update_extension($current = '')
	{
		if ($current == '' OR $current == $this->version)
		{
			return FALSE;
		}
		
		$this->EE->db->where('class', __CLASS__);
		$this->EE->db->update(
					'extensions', 
					array('version' => $this->version)
		);
	}
	// END


	/**
	 * First attempt to get settings via global variables or config object
	 *
	 * @return boolean TRUE if settings found; FALSE otherwise
	 */
	function _get_global_or_config_settings() {

		// if values are coming from config, use these
		if($this->EE->config->item('minimee_cache_path') && $this->EE->config->item('minimee_cache_url'))
		{
			$this->settings['cache_path'] = $this->EE->config->item('minimee_cache_path');
			$this->settings['cache_url'] = $this->EE->config->item('minimee_cache_url');
			$this->settings['disable'] = $this->EE->config->item('minimee_disable'); // optional
			$this->settings['strict'] = $this->EE->config->item('minimee_strict'); // optional
			
			log_message('debug', 'Minimee has retrieved settings from config.');
			return TRUE;

		} // else if values are in global variable, use these
		elseif (array_key_exists('minimee_cache_path', $this->EE->config->_global_vars) && array_key_exists('minimee_cache_url', $this->EE->config->_global_vars))
		{
			$this->settings['cache_path'] = $this->EE->config->_global_vars['minimee_cache_path'];
			$this->settings['cache_url'] = $this->EE->config->_global_vars['minimee_cache_url'];

			// optional
			if (array_key_exists('minimee_disable', $this->EE->config->_global_vars))
			{
				$this->settings['disable'] = $this->EE->config->_global_vars['minimee_disable'];
			}

			// optional
			if (array_key_exists('minimee_strict', $this->EE->config->_global_vars))
			{
				$this->settings['strict'] = $this->EE->config->_global_vars['minimee_strict'];
			}
			
			log_message('debug', 'Minimee has retrieved settings from global variables.');
			return TRUE;

		}
		else
		{
			return FALSE;
		}
	}
	// END

	
	/**
	 * Standardise settings just to be safe!
	 *
	 * @return void
	 */
	function _normalize_settings()
	{
		$this->settings['disable'] = ($this->settings['disable'] === TRUE OR strtolower($this->settings['disable']) === 'true' OR strtolower($this->settings['disable']) === 'yes' OR $this->settings['disable'] === '1') ? TRUE : FALSE; // default = FALSE
		$this->settings['strict'] = ($this->settings['strict'] === TRUE OR strtolower($this->settings['strict']) === 'true' OR strtolower($this->settings['strict']) === 'yes' OR $this->settings['strict'] === '1') ? TRUE : FALSE; // default = FALSE
		$this->settings['cache_path'] = rtrim($this->settings['cache_path'], '/');
		$this->settings['cache_url'] = rtrim($this->settings['cache_url'], '/');
	}
	// END
	
}
// END CLASS

	
/* End of file ext.minimee.php */ 
/* Location: ./system/expressionengine/third_party/minimee/ext.minimee.php */