<?php
if ( ! defined('BASEPATH')) exit('No direct script access allowed');

$plugin_info = array(
	'pi_name'			=> 'Minimee',
	'pi_version'		=> '1.0.2',
	'pi_author'			=> 'John D Wells',
	'pi_author_url'		=> 'http://johndwells.com/software/minimee',
	'pi_description'	=> 'Minimee: minimize & combine your CSS and JS files. For EE2 only.',
	'pi_usage'			=> Minimee::_usage()
);

/**
 * Minimee: minimize & combine your CSS and JS files. For EE2 only.
 * @version 1.0.2
 * @author John D Wells <http://johndwells.com>
 * @license http://www.opensource.org/licenses/bsd-license.php BSD license
 * @link	http://johndwells.com/software/minimee
 */
class Minimee {

	var $cache_path;
	var $cache_url;
	var $media;
	var $minify;
	var $combine;
	var $disable;
	var $queue;
	var $strict;
	var $openSSL;

	var $filesdata = array();
	var $stylesheet_query = array();

	var $EE;
	var $ext;


	/**
	 * Constructor
	 *
	 * @return void
	 */
	function Minimee()
	{
		$this->EE =& get_instance();
		
		$this->_init();
	}
	// END


	/**
	 * Plugin function: exp:minimee:css
	 * 
	 * @return mixed string or empty
	 */
	function css()
	{
		return $this->_run('css');
	}
	// END


	/**
	 * Plugin function: exp:minimee:display
	 * 
	 * @return mixed string or empty
	 */
	function display()
	{

		// see which to display
		$js = strtolower($this->EE->TMPL->fetch_param('js'));
		$css = strtolower($this->EE->TMPL->fetch_param('css'));
		$out = '';
		
		if ($js)
		{
			$out .= $this->_display('js');
		}

		if ($css)
		{
			$out .= $this->_display('css');
		}
		
		return $out;
	}
	// END


	/**
	 * Plugin function: exp:minimee:js
	 * 
	 * @return mixed string or empty
	 */
	function js()
	{
		return $this->_run('js');
	}
	// END


	/** 
	 * Internal function for writing cache files
	 * [Adapted from CodeIgniter Carabiner library]
	 * 
	 * @param	String of filename of the new file
	 * @param	String of contents of the new file
	 * @return	boolean	Returns true on successful cache, false on failure
	 */
	function _cache($filename, $file_data)
	{
		$filepath = $this->cache_path . '/' . $filename;
		$success = file_put_contents($filepath, $file_data);
		
		if ($success)
		{ 
			log_message('debug', 'Minimee: Cache file ' . $filename . ' was written to ' . $this->cache_path);
			return TRUE;
		}
		else
		{
			log_message('error', 'Minimee: There was an error writing cache file ' . $filename . ' to ' . $this->cache_path);
			return FALSE;
		}
	}
	// END
	
	
	/**
	 * Checks if PHP configuration supports file_get_contents() over SSL
	 * 
	 * @return void
	 */
	function _check_openssl()
	{
		if ($this->openSSL)
		{
			if ( ! defined('OPENSSL_VERSION_NUMBER'))
			{
				$this->disable = TRUE;
				log_message('error', 'Minimee has been disabled; your PHP compile does not appear to support file_get_contents() over SSL.');
			}
		}
	}
	// END


	/**
	 * If in strict mode, verify first that all files exist
	 *
	 * @return void
	 */	
	function _check_strict()
	{
	
		// if in strict mode, be sure every file exists
		if ($this->strict)
		{
			$this->_fetch_headers();
			
			foreach ($this->filesdata as $key => $file) 
			{
				if($file['http_code'] >= 400)
				{
					$this->disable = TRUE;
					log_message('debug', 'Minimee has been disabled: strict mode has detected a missing file, ' . $file['name'] . '; HTTP response code was: ' . $this->filesdata[$key]['http_code']);
				}
			}
		}
	}
	// END


	/** 
	 * Internal function for compressing/combining scripts
	 * [Adapted from CodeIgniter Carabiner library]
	 * 
	 * @param	String flag the asset type: css|js
	 * @param	String of the filename of the file-to-be
	 * @param	boolean whether or not to minify
	 * @return	None
	 */
	function _combine($flag, $filename, $minify)
	{
		$file_data = '';
		foreach ($this->filesdata as $key => $file) :

			if ($minify)
			{
				$file_data .= $this->_minify($flag, $key) . "\n";
			}	
			else
			{
				switch ($file['type']) :

					case ('stylesheet') :
					case ('remote') :
						if($file['http_code'] < 400)
						{
							// I hate to suppress errors, but it's only way to avoid one from a 404 response
							$response = @file_get_contents($file['name']);
							if($response && (substr($http_response_header[0], 9, 3) < 400))
							{
								$file_data .= $response . "\n";
							}
						}
					break;

					case ('local') :					
					default :
						if ($file['http_code'] < 400)
						{
							$file_data .= file_get_contents(realpath(FCPATH . '/' . $file['name']));
						}
					break;

				endswitch;

			}
		
		endforeach;
		
		$this->_cache($filename, $file_data);

	}
	// END


	/**
	 * Processes and displays queue
	 *
	 * @param string either 'js' or 'css'
	 * @return string The final output from Minimee::out()
	 */	
	function _display($type)
	{
		// Return immediately if already disabled (via config or flightcheck error)
		if ($this->disable) return;
		
		// Fetch parameters from tag pair
		$this->_fetch_params($type);

		// Return if disabled via parameter
		if ($this->disable) return;

		// Was a queue passed?
		if ( ! $this->queue)
		{
			log_message('error', 'Minimee was not provided a queue to display.');
			return;
		}

		// retrieve queued files from session cache
		$this->_fetch_queue($type);

		// if in strict mode, be sure every file exists
		$this->_check_strict();
		
		// need to verify that we can, if need be, grab a file over ssl
		$this->_check_openssl();

		// Last check if Disabled, cause by strict mode or failing openSSL check
		if ($this->disable)
		{
			// let's return all tags re-created
			$out = '';
			foreach ($this->filesdata as $file)
			{
				$out .= $this->_tag($type, $file['name'], $this->media, FALSE);
			}
			return $out;
		}
		
		// No files found?
		if ( ! is_array($this->filesdata) OR count($this->filesdata) == 0)
		{
			log_message('error', 'Minimee did not find any queued files to display.');
			return;
		}

		return $this->_out($type);
	}
	// END
	
	
	/**
	 * Retrieve files from cache
	 *
	 * @param string either 'js' or 'css'
	 * @return void
	 */	
	function _fetch_queue($type)
	{
		if ( ! array_key_exists('minimee', $this->EE->session->cache)) return;

		if ( ! array_key_exists($type, $this->EE->session->cache['minimee'])) return;

		if ( ! array_key_exists($this->queue, $this->EE->session->cache['minimee'][$type])) return;
		
		// clear queue just in case
		$this->filesdata = array();

		// set our Minimee::files & Minimee::filesdata arrays
		$this->_set_filesdata($this->EE->session->cache['minimee'][$type][$this->queue]);
	}
	// END
	

	/**
	 * Parse tagdata for <link> and <script> tags,
	 * pulling out href & src attributes respectively.
	 * [Adapted from SL Combinator]
	 * 
	 * @param string tagdata
	 * @param string either css or js
	 * @return void
	 */
	function _fetch_files($haystack, $type)
	{
		switch (strtolower($type)) :

			case 'css' :
				$pat = "/<link{1}.*?href=['|\"']{1}(.*?)['|\"]{1}/i";
				break;
				
			case 'js' :
				$pat = "/<script{1}.*?src=['|\"]{1}(.*?)['|\"]{1}/i";
				break;
				
			default :
				return FALSE;
				break;

		endswitch;
		
		if (preg_match_all($pat, $haystack, $matches, PREG_PATTERN_ORDER))
		{
			// set our files & filesdata arrays
			$this->_set_filesdata($matches[1]);
		}
	}
	// END


	/**
	 * Find out more info about each file
	 * Attempts to get file modification times, determine what files exist, etc
	 * 
	 * @return void
	 */
	function _fetch_headers()
	{
		// query for any stylesheets	
		$stylesheet_versions = $this->_fetch_stylesheet_versions();

		// now, loop through our filesdata and set all headers	
		foreach ($this->filesdata as $key => $file) :

			switch ($file['type']) :
			
				case ('stylesheet') :

					if ($stylesheet_versions && array_key_exists($file['stylesheet'], $stylesheet_versions))
					{
						// transform name out of super global and into valid URL
						$this->filesdata[$key]['name'] = $this->EE->functions->fetch_site_index().QUERY_MARKER.'css='.$file['stylesheet'].(($this->EE->config->item('send_headers') == 'y') && isset($stylesheet_versions[$file['stylesheet']]) ? '.v.'.$stylesheet_versions[$file['stylesheet']] : '');
						$this->filesdata[$key]['lastmodified'] = $stylesheet_versions[$file['stylesheet']];
						$this->filesdata[$key]['http_code'] = 200;
					}
					else
					{
						//if no versioning was found, let's assume the template does not exist
						$this->filesdata[$key]['http_code'] = 404;
					}

				break;
				
				case ('remote') :
				
					// it's too costly to check if a remote file exists, so we will assume here that it simply exists
					$this->filesdata[$key]['http_code'] = 200;
					
				break;
				
				case ('local') :
				default :

					$realpath = realpath(FCPATH . '/' . $file['name']);
					if (file_exists($realpath))
					{
						$this->filesdata[$key]['http_code'] = 200;
						$this->filesdata[$key]['lastmodified'] = filemtime($realpath);
						$this->filesdata[$key]['lastmodified'] = ($this->filesdata[$key]['lastmodified'] == 0) ? '0000000000' : $this->filesdata[$key]['lastmodified'];
					}
					else
					{
						$this->filesdata[$key]['http_code'] = 404;
					}

				break;
			
			endswitch;

		endforeach;

	}
	// END
	
	
	/**
	 * Fetch parameters from $this->EE->TMPL
	 * 
	 * @param mixed either css/js or NULL
	 * @return mixed string or empty
	 */
	function _fetch_params($type = '')
	{
		// if we pass a type in, then substitute that param value for queue
		// this only happens when Minimee::display() is called,
		// and a queued list of files needs to be output
		// type will either be 'js' or 'css'

		if ($type)
		{
			$this->queue = strtolower($this->EE->TMPL->fetch_param($type));
		}
		else
		{
			$this->queue = strtolower($this->EE->TMPL->fetch_param('queue'));
			$this->queue = ($this->queue == '' OR $this->queue == 'false' OR $this->queue == 'no' OR $this->queue == '0') ? FALSE : $this->queue; // default = FALSE
		}
	
		$this->media = ($this->EE->TMPL->fetch_param('media')) ? strtolower($this->EE->TMPL->fetch_param('media')) : 'screen'; // default = 'screen'
		
		$this->combine = strtolower($this->EE->TMPL->fetch_param('combine'));
		$this->combine = ($this->combine == 'false' OR $this->combine == 'no' OR $this->combine == '0') ? FALSE : TRUE; // default = TRUE
		
		$this->minify = strtolower($this->EE->TMPL->fetch_param('minify'));
		$this->minify = ($this->minify == 'false' OR $this->minify == 'no' OR $this->minify == '0') ? FALSE : TRUE; // default = TRUE

		// only fetch strict parameter if strict mode has NOT been set via DB or global variable
		if ( ! $this->strict)
		{
			$this->strict = strtolower($this->EE->TMPL->fetch_param('strict'));
			$this->strict = ($this->strict == 'yes' OR $this->strict == 'true' OR $this->strict == '1') ? TRUE : FALSE; // default = FALSE
		}

		// only fetch disable parameter if plugin has NOT been disabled via DB or global variable
		if ( ! $this->disable)
		{
			$this->disable = strtolower($this->EE->TMPL->fetch_param('disable'));
			$this->disable = ($this->disable == 'yes' OR $this->disable == 'true' OR $this->disable == '1') ? TRUE : FALSE; // default = FALSE
		}
	}
	// END


	/**
	 * Query DB for any stylesheets
	 * Borrowed from $EE->TMPL->parse_globals(): ./system/expressionengine/libraries/Template.php
	 *
	 * @return mixed array or FALSE
	 */
	function _fetch_stylesheet_versions() {
	
		// nothing to do if Minimee::stylesheet_query is empty
		if ( ! $this->stylesheet_query) return FALSE;

		$versions = array();
		
		$sql = "SELECT t.template_name, tg.group_name, t.edit_date, t.save_template_file FROM exp_templates t, exp_template_groups tg
				WHERE  t.group_id = tg.group_id
				AND    t.template_type = 'css'
				AND    t.site_id = '".$this->EE->db->escape_str($this->EE->config->item('site_id'))."'";
	
		$css_query = $this->EE->db->query($sql.' AND ('.implode(' OR ', $this->stylesheet_query) .')');
		
		if ($css_query->num_rows() > 0)
		{
			foreach ($css_query->result_array() as $row)
			{
				$versions[$row['group_name'].'/'.$row['template_name']] = $row['edit_date'];

				if ($this->EE->config->item('save_tmpl_files') == 'y' AND $this->EE->config->item('tmpl_file_basepath') != '' AND $row['save_template_file'] == 'y')
				{
					$basepath = $this->EE->config->slash_item('tmpl_file_basepath').$this->EE->config->item('site_short_name').'/';
					$basepath .= $row['group_name'].'.group/'.$row['template_name'].'.css';
					
					if (is_file($basepath))
					{
						$versions[$row['group_name'].'/'.$row['template_name']] = filemtime($basepath);
					}
				}
			}
		}
		else
		{
			return FALSE;
		}
			
		return $versions;
	}
	// END


	/**
	 * Initialise: retrieve settings, perform flightchecks
	 *
	 * @return void
	 */
	function _init()
	{
	
		// have we already initialised once?
		if ( ! isset($this->EE->session->cache['minimee']['settings']))
		{
			// Get settings with help of our extension
			if ( ! class_exists('Minimee_ext'))
			{
				require_once(PATH_THIRD . 'minimee/ext.minimee.php');
			}
			$this->ext = new Minimee_ext();
			$this->ext->get_settings();
		}

		// grab settings
		$this->disable = $this->EE->session->cache['minimee']['settings']['disable'];
		$this->strict = $this->EE->session->cache['minimee']['settings']['strict'];
		$this->cache_path = $this->EE->session->cache['minimee']['settings']['cache_path'];
		$this->cache_url = $this->EE->session->cache['minimee']['settings']['cache_url'];
	
		// Flightcheck: determine if we can continue or disable permanently
		switch ('flightcheck') :

			case ( ! $this->cache_path) :
			case ( ! $this->cache_url) :
				$this->disable = TRUE;
				log_message('error', 'Minimee not configured: please set a cache path and/or url.');
			break;

			case ( ! file_exists($this->cache_path)) :
			case ( ! is_writable($this->cache_path)) :
				$this->disable = TRUE;
				log_message('error', 'Minimee has been disabled: your cache folder does not exist or is not writable.');
			break;

			case ($this->disable) :
				log_message('debug', 'Minimee plugin has passed flightcheck, but is disabled.');
			break;

			default :
				log_message('debug', 'Minimee plugin has passed flightcheck.');
			break;

		endswitch;
	}
	// END


	/** 
	 * Internal function for minifying assets
	 * [Adapted from CodeIgniter Carabiner library]
	 * 
	 * @param	String flag the asset type: css|js
	 * @param	Integer key to Minimee::filesdata() array
	 * @return	String minified contents of file
	 */
	function _minify($flag, $key)
	{
	
		// file does not exist so return
		if ($this->filesdata[$key]['http_code'] >= 400) return;

		$contents = '';

		switch ($this->filesdata[$key]['type']) :

			case ('stylesheet');
			case ('remote') :
				if ($this->filesdata[$key]['http_code'] < 400)
				{
					// I hate to suppress errors, but it's only way to avoid one from a 404 response
					$response = @file_get_contents($this->filesdata[$key]['name']);
					if ($response && (substr($http_response_header[0], 9, 3) < 400))
					{
						$contents = $response . "\n";
					}
				}
			break;
			
			case ('local') :
			default :
				if ($this->filesdata[$key]['http_code'] < 400)
				{
					$rel = dirname(rtrim($this->EE->config->config['base_url'], '/') . '/' . ltrim($this->filesdata[$key]['name'], '/')) . '/';
					$contents = file_get_contents(realpath(FCPATH . '/' . $this->filesdata[$key]['name'])) . "\n";
				}
			break;

		endswitch;

		switch ($flag) :
			
			case 'js':
				require_once('libraries/jsmin.php');
				$this->jsmin = new jsmin();
				return $this->jsmin->minify($contents);
			break;
			
			case 'css':
				require_once('libraries/cssmin.php');
				$this->cssmin = new cssmin();
				
				// set a relative path if exists
				if (isset($rel))
				{
					$this->cssmin->config(array('relativePath' => $rel));
				}

				return $this->cssmin->minify($contents);
			break;

		endswitch;
	
	}
	// END
	
	
	/**
	 * Performs heavy lifting of plugin, processing output and returning final tags
	 * [Adapted from CodeIgniter Carabiner library]
	 * 
	 * @param string either 'js' or 'css'
	 * @return string The final tag to be returned to template
	 */	
	function _out($type)
	{

		// If for some reason we do not want to minify or combine, then why are we here?
		if ( ! $this->combine && ! $this->minify) return $this->EE->TMPL->tagdata;
		
		// our return variable	
		$out = '';

		// if we are in strict mode, we can assume we've already retrieved our headers
		if ( ! $this->strict)
		{
			$this->_fetch_headers();
		}

		// if we are not combining, then minify each file
		if ( ! $this->combine) :

			foreach ($this->filesdata as $key => $file) :
			
				if ($file['http_code'] < 400)
				{
					$filename = $file['lastmodified'] . md5($file['name']) . '.' . $type;

					if ( ! file_exists($this->cache_path . '/' . $filename))
					{
						$this->_cache($filename, $this->_minify($type, $key) . "\n");
					}
					else
					{
						log_message('debug', 'Minimee is returning a cached file: ' . $this->cache_path . '/' . $filename);
					}
	
					$out .= $this->_tag($type, $filename, $this->media);
				}

			endforeach;

		// combine & minify files
		else :
		
			$lastmodified = 0;
			$cache_name = '';

			foreach ($this->filesdata as $key => $file)
			{
				if ($file['http_code'] < 400)
				{
					$lastmodified = max($lastmodified, $file['lastmodified'] );
					$cache_name .= $file['name'];
				}
			}

			$lastmodified = ($lastmodified == 0) ? '0000000000' : $lastmodified;
			$filename = $lastmodified . md5($cache_name) . '.' . $type;
	
			if ( ! file_exists($this->cache_path . '/' . $filename))
			{
				$this->_combine($type, $filename, $this->minify);
			}
			else
			{
				log_message('debug', 'Minimee is returning a cached file: ' . $this->cache_path . '/' . $filename);
			}

			$out = $this->_tag($type, $filename, $this->media);

		endif;
		
		return $out;
	}
	//END
	
	
	/**
	 * Called by Minimee:css and Minimee:js, performs basic run command
	 * 
	 * @param string either 'js' or 'css'
	 * @return mixed string or empty
	 */
	function _run($type)
	{
		// Return immediately if already disabled (via config or flightcheck error)
		if ($this->disable) return $this->EE->TMPL->tagdata;
		
		// Fetch parameters passed in tag pair
		$this->_fetch_params();

		// disabled via tag pair?
		if ($this->disable) return $this->EE->TMPL->tagdata;

		// Parse contents and look for files
		$this->_fetch_files($this->EE->TMPL->tagdata, $type);

		// Are we queueing for later? If so, just save in session
		if($this->queue) return $this->_set_queue($type);

		// if in strict mode, be sure every file exists
		$this->_check_strict();
		
		// need to verify that we can, if need be, grab a file over ssl
		$this->_check_openssl();

		// Last check if Disabled, cause by strict mode or failing openSSL check
		if ($this->disable) return $this->EE->TMPL->tagdata;

		// No files found?
		if ( ! is_array($this->filesdata) OR count($this->filesdata) == 0)
		{
			log_message('error', 'Minimee was not passed any valid files to process.');
			return $this->EE->TMPL->tagdata;
		}

		// If for some reason we do not want to minify or combine, then why are we here?
		if ( ! $this->combine && ! $this->minify) return $this->EE->TMPL->tagdata;

		// Let's roll: process and return output		
		return $this->_out($type);
	}
	// END


	/**
	 * Set up our Minimee::files and Minimee::filesdata arrays to prepare for processing
	 * 
	 * @param array array of files
	 * @return void
	 */
	function _set_filesdata($files) {
	
		$dups = array();
	
		foreach ($files as $key => $file)
		{
			// try to avoid duplicates
			if (in_array($file, $dups)) continue;
		
			$dups[] = $file;
		
			$this->filesdata[$key] = array(
				'name' => $file,
				'type' => NULL,
				'lastmodified' => '0000000000',
				'stylesheet' => NULL,
				'http_code' => NULL
			);
			
			$this->_set_filesdata_type($key);
			
			// check need for openSSL support
			$this->openSSL = (strpos('https://', $file)) ? TRUE : FALSE;
		}
		
		unset($dups);
	}
	// END
	

	/**
	 * Determine what file type it is
	 * 
	 * @param int key value to Minimee::filesdata array
	 * @return void
	 */
	function _set_filesdata_type($key) {

		// from old _isURL() file from Carabiner Asset Management Library
		if (preg_match('@(https?://([-\w\.]+)+(:\d+)?(/([\w/_\.]*(\?\S+)?)?)?)@', $this->filesdata[$key]['name']) > 0)
		{
			$this->filesdata[$key]['type'] = 'remote';
		}
		elseif (strpos($this->filesdata[$key]['name'], 'stylesheet=') !== FALSE && preg_match("/".LD."\s*stylesheet=[\042\047]?(.*?)[\042\047]?".RD."/", $this->filesdata[$key]['name'], $matches))
		{
			$this->filesdata[$key]['type'] = 'stylesheet';
			$this->filesdata[$key]['stylesheet'] = $matches[1];

			// prepare part of our SQL query for later			
			$ex = explode('/', $matches[1], 2);
			if (isset($ex[1]))
			{
				$this->stylesheet_query[] = "(t.template_name = '".$this->EE->db->escape_str($ex[1])."' AND tg.group_name = '".$this->EE->db->escape_str($ex[0])."')";
			}
		}
		else
		{
			$this->filesdata[$key]['type'] = 'local';
		}
	}
	// END

	
	/** 
	 * Adds the files to be queued into session
	 * 
	 * @param string either 'js' or 'css'
	 * @return void
	 */
	function _set_queue($type)
	{
		// We are being overly safe here, but in theory the cache has already been configured
		if ( ! array_key_exists('minimee', $this->EE->session->cache))
		{
			$this->EE->session->cache['minimee'] = array();
		}
		
		if ( ! array_key_exists($type, $this->EE->session->cache['minimee']))
		{
			$this->EE->session->cache['minimee'][$type] = array();
		}
		
		if ( ! array_key_exists($this->queue, $this->EE->session->cache['minimee'][$type]))
		{
			$this->EE->session->cache['minimee'][$type][$this->queue] = array();
		}

		// Add all files to the qeue cache
		foreach ($this->filesdata as $file)
		{
			if ( ! in_array($file['name'], $this->EE->session->cache['minimee'][$type][$this->queue]))
			{
				$this->EE->session->cache['minimee'][$type][$this->queue][] = $file['name'];
			}
		}
	}
	// END
	

	/** 
	 * Internal function for making tag strings
	 * [Adapted from CodeIgniter Carabiner library]
	 * 
	 * @param	String	flag for type: css|js
	 * @param	String	Tilename
	 * @param	String	Media type for the tag. Only applies to CSS.
	 * @param	Boolean Whether the tag is for a cached file or not (default TRUE)
	 * @return	String containing an HTML tag reference to given reference
	 */
	function _tag($flag, $filename, $media = 'screen', $cache = TRUE)
	{
	
		// only prepend cache_url if needed
		$base_url = ($cache) ? $this->cache_url . '/' : '';

		switch ($flag) :
		
			case 'css':
				return '<link type="text/css" rel="stylesheet" href="' . $base_url . $filename . '" media="' . $media . '" />'."\r\n";
			break;

			case 'js':
				return '<script type="text/javascript" src="' . $base_url . $filename . '" charset="' . $this->EE->config->item('charset') . '"></script>'."\r\n";
			break;
		
		endswitch;
	
	}
	// END


	/**
	 * Display usage notes in EE control panel
	 *
	 * @return string Usage notes
	 */	
	function _usage()
	{
		ob_start(); 
?>

Please see http://johndwells.com/software/minimee for complete and up-to-date documentation.

=====================================================
Basic Usage
=====================================================

CSS:
{exp:minimee:css media="screen"}
	<link type="text/css" rel="stylesheet" href="/css/screen.css" media="screen" />
{/exp:minimee:css}

JS:
{exp:minimee:js}
	<script type="text/javascript" src="scripts/jquery.easing.1.3.js"></script>
{/exp:minimee:js}


=====================================================
Parameters
=====================================================

media="screen" (optional - CSS only)
- sets the media attribute for the final output of the <link> tag

disable="false"
- set to "TRUE" if you wish to temporarily disable this usage of plugin

minify="true"
- tells the plugin whether to minify files when caching; if set to FALSE,
  it will not run files through minify engine

combine="true"
- tells plugin whether to combine files when caching; if set to FALSE,
  it will cache each file separately

queue="name"
- Allows you to create a queue of assets to be output at a later stage in code.
- The string passed to the queue parameter can later be used in the
  exp:minimee:display single tags. See online docs for more info and examples.

* Note: if minify & combine are both set to false, it performs no caching,
  effectively disabling plugin

		
<?php
		$buffer = ob_get_contents();
		ob_end_clean(); 
		return $buffer;
	}
}
	
/* End of file pi.minimee.php */ 
/* Location: ./system/expressionengine/third_party/minimee/pi.minimee.php */